==> deepeval-0.8.0.tar.gz: deepeval-0.8.0/deepeval/metrics/bias_classifier.py <==
"""Metric for bias classifier - using the same min score subtraction methodology as the toxic classifier 
Rationale for bias classifier is described here https://arxiv.org/pdf/2208.05777.pdf
1 - Not Biased
0 - Bias
"""

import warnings
from .metric import Metric


class UnBiasedMetric(Metric):
    def __init__(
        self, model_name: str = "original", minimum_score: float = 0.5
    ):  # see paper for rationale https://arxiv.org/pdf/2208.05777.pdf
        self.model_name = model_name
        self.minimum_score = minimum_score

    def measure(self, text: str):
        from Dbias.bias_classification import classifier

        warnings.warn(
            "Run `pip install deepeval[bias]`. If you have, please ignore this warning."
        )

        results = classifier(text)
        # sample output
        # [{'label': 'Biased', 'score': 0.9938021898269653}]
        if results[0]["label"] == "Biased":
            v = 0.5 - (results[0]["score"] / 2)
        else:
            # if it's unbiased - use normal score
            v = 0.5 + (results[0]["score"] / 2)

        self.success = False
        if v > self.minimum_score:
            self.success = True

        return v

    def is_successful(self):
        return self.success

    @property
    def __name__(self):
        return "Bias Score"


def assert_unbiased(
    text: str, minimum_score: float = 0.5
):  # see paper for rationale https://arxiv.org/pdf/2208.05777.pdf
    metric = UnBiasedMetric(minimum_score=minimum_score)
    score = metric.measure(text)
    assert metric.is_successful(), f"Text is biased - got {score}"

==> deepeval-0.10.3.tar.gz: deepeval-0.10.3/deepeval/metrics/bias_classifier.py <==
"""Metric for bias classifier - using the same min score subtraction methodology as the toxic classifier 
Rationale for bias classifier is described here https://arxiv.org/pdf/2208.05777.pdf
1 - Not Biased
0 - Bias
"""

import warnings
from typing import Optional
from .metric import Metric
from ..singleton import Singleton


class UnBiasedMetric(Metric, metaclass=Singleton):
    def __init__(
        self, model_name: str = "original", minimum_score: float = 0.5
    ):  # see paper for rationale https://arxiv.org/pdf/2208.05777.pdf
        self.model_name = model_name
        self.minimum_score = minimum_score

    def __call__(self, output, expected_output, query: Optional[str] = "-"):
        score = self.measure(output, expected_output)
        success = score >= self.minimum_score
        self._send_to_server(
            metric_score=score,
            metric_name=self.__name__,
            query=query,
            output=output,
            expected_output=expected_output,
            success=success,
        )
        return score

    def measure(self, text: str):
        from Dbias.bias_classification import classifier

        warnings.warn(
            "Run `pip install deepeval[bias]`. If you have, please ignore this warning."
        )

        results = classifier(text)
        # sample output
        # [{'label': 'Biased', 'score': 0.9938021898269653}]
        if results[0]["label"] == "Biased":
            v = 0.5 - (results[0]["score"] / 2)
        else:
            # if it's unbiased - use normal score
            v = 0.5 + (results[0]["score"] / 2)

        self.success = False
        if v > self.minimum_score:
            self.success = True

        return v

    def is_successful(self):
        return self.success

    @property
    def __name__(self):
        return "Bias Score"


def assert_unbiased(
    text: str, minimum_score: float = 0.5
):  # see paper for rationale https://arxiv.org/pdf/2208.05777.pdf
    metric = UnBiasedMetric(minimum_score=minimum_score)
    score = metric.measure(text)
    assert metric.is_successful(), f"Text is biased - got {score}"
